<?php

/** 
 * Plugin Name: WP Link Bio
 * Plugin URI: https://blastmkt.com/wp-link-bio
 * Description: Add unlimited links to bio using your branded domain.
 * Version: 1.1.0
 * Author: Blast Marketing
 * Author URI: https://blastmkt.com/
 * License: GPLv2
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: wp-link-bio
 * Domain Path: /languages
 * {Plugin Name} is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * any later version.
 *  
 * {Plugin Name} is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with {Plugin Name}. If not, see {URI to Plugin License}.
 *
*/
if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( function_exists( 'wplb_fs' ) ) {
    wplb_fs()->set_basename( false, __FILE__ );
} else {
    
    if ( !function_exists( 'wplb_fs' ) ) {
        // Create a helper function for easy SDK access.
        function wplb_fs()
        {
            global  $wplb_fs ;
            
            if ( !isset( $wplb_fs ) ) {
                // Include Freemius SDK.
                require_once dirname( __FILE__ ) . '/freemius/start.php';
                $wplb_fs = fs_dynamic_init( array(
                    'id'              => '3932',
                    'slug'            => 'wp-link-bio',
                    'premium_slug'    => 'wp-link-bio-pro',
                    'type'            => 'plugin',
                    'public_key'      => 'pk_ccfdf6ca1145a1848f0514a626e1d',
                    'is_premium'      => false,
                    'premium_suffix'  => '(Pro)',
                    'has_addons'      => false,
                    'has_paid_plans'  => true,
                    'trial'           => array(
                    'days'               => 7,
                    'is_require_payment' => false,
                ),
                    'has_affiliation' => 'selected',
                    'menu'            => array(
                    'slug'        => 'edit.php?post_type=wp-link-bio',
                    'support'     => false,
                    'affiliation' => false,
                ),
                    'is_live'         => true,
                ) );
            }
            
            return $wplb_fs;
        }
        
        // Init Freemius.
        wplb_fs();
        // Signal that SDK was initiated.
        do_action( 'wplb_fs_loaded' );
    }
    
    function wplb_activate()
    {
        wplb_setup_post_type();
        wplb_admin_enqueue_scripts();
        flush_rewrite_rules();
    }
    
    register_activation_hook( __FILE__, 'wplb_activate' );
    function wplb_deactivate()
    {
        unregister_post_type( 'wp-link-bio' );
        flush_rewrite_rules();
    }
    
    register_deactivation_hook( __FILE__, 'wplb_deactivate' );
    function wplb_add_plugin_page_settings_link( $links )
    {
        $links[] = '<a href="' . admin_url( 'edit.php?post_type=wp-link-bio&page=wp-link-bio' ) . '">' . __( 'Settings', 'wp-link-bio' ) . '</a>';
        return $links;
    }
    
    add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'wplb_add_plugin_page_settings_link' );
    function wplb_setup_post_type()
    {
        register_post_type( 'wp-link-bio', [
            'labels'       => [
            'menu_name'     => 'WP Link Bio',
            'name'          => __( 'Links', 'wp-link-bio' ),
            'singular_name' => __( 'Link', 'wp-link-bio' ),
            'add_new'       => _x( 'Add New Link', 'wp-link-bio' ),
            'all_items'     => __( 'All Links', 'wp-link-bio' ),
        ],
            'rewrite'      => [
            'slug' => 'link',
        ],
            'public'       => true,
            'show_in_rest' => true,
            'rest_base'    => 'wp-link-bio',
            'supports'     => [
            'title',
            'thumbnail',
            'page-attributes',
            'custom-fields'
        ],
            'menu_icon'    => 'dashicons-admin-links',
            'capability'   => 'page',
        ] );
        add_image_size(
            'wplb_square',
            500,
            500,
            true
        );
    }
    
    add_action( 'init', 'wplb_setup_post_type' );
    function wplb_admin_enqueue_scripts()
    {
        wp_enqueue_media();
        wp_enqueue_style( 'wp-color-picker' );
        wp_enqueue_script(
            'wplb_script',
            plugins_url( 'js/wp-link-bio.js', __FILE__ ),
            array( 'jquery', 'wp-color-picker' ),
            '',
            true
        );
    }
    
    add_action( 'admin_enqueue_scripts', 'wplb_admin_enqueue_scripts' );
    function wplb_options_page()
    {
        add_submenu_page(
            'edit.php?post_type=wp-link-bio',
            'WP Link Bio',
            __( 'Settings', 'wp-link-bio' ),
            'manage_options',
            'wp-link-bio',
            'wplb_options_page_html'
        );
    }
    
    add_action( 'admin_menu', 'wplb_options_page' );
    function wplb_settings()
    {
        add_settings_section(
            'wplb_section_general_settings',
            __( 'Settings', 'wp-link-bio' ),
            false,
            //'wplb_section_general_settings_cb',
            'wp-link-bio'
        );
        register_setting( 'wp-link-bio', 'wplb_link_bio' );
        register_setting( 'wp-link-bio', 'wplb_endpoint' );
        register_setting( 'wp-link-bio', 'wplb_logo_url' );
        register_setting( 'wp-link-bio', 'wplb_body_bg_color' );
        register_setting( 'wp-link-bio', 'wplb_body_link_color' );
        $endpoint = get_option( 'wplb_endpoint' );
        if ( $endpoint ) {
            add_settings_field(
                'wplb_link_bio',
                __( 'Your Link', 'wp-link-bio' ),
                'wplb_link_bio_cb',
                'wp-link-bio',
                'wplb_section_general_settings',
                [
                'label_for' => 'wplb_link_bio',
                'class'     => 'wplb-row',
            ]
            );
        }
        add_settings_field(
            'wplb_endpoint',
            __( 'Page', 'wp-link-bio' ),
            'wplb_endpoint_cb',
            'wp-link-bio',
            'wplb_section_general_settings',
            [
            'label_for' => 'wplb_endpoint',
            'class'     => 'wplb-row',
        ]
        );
        add_settings_field(
            'wplb_logo_url',
            __( 'Photo or Logo', 'wp-link-bio' ),
            'wplb_logo_url_cb',
            'wp-link-bio',
            'wplb_section_general_settings',
            [
            'label_for' => 'wplb_logo_url',
            'class'     => 'wplb-row',
        ]
        );
        add_settings_field(
            'wplb_body_bg_color',
            __( 'Background Color', 'wp-link-bio' ),
            'wplb_body_bg_color_cb',
            'wp-link-bio',
            'wplb_section_general_settings',
            [
            'label_for'   => 'wplb_body_bg_color',
            'class'       => 'wplb-row',
            'placeholder' => '#ffffff',
        ]
        );
        add_settings_field(
            'wplb_body_link_color',
            __( 'Link Color', 'wp-link-bio' ),
            'wplb_body_link_color_cb',
            'wp-link-bio',
            'wplb_section_general_settings',
            [
            'label_for'   => 'wplb_body_link_color',
            'class'       => 'wplb-row',
            'placeholder' => '#000000',
        ]
        );
        add_settings_section(
            'wplb_section_integration_settings',
            __( 'Integrations', 'wp-link-bio' ),
            false,
            //'wplb_section_integration_settings_cb',
            'wp-link-bio'
        );
        register_setting( 'wp-link-bio', 'wplb_fb_pixel_id' );
        register_setting( 'wp-link-bio', 'wplb_ga_tracking_code' );
        register_setting( 'wp-link-bio', 'wplb_gtm_code' );
        add_settings_field(
            'wplb_fb_pixel_id',
            __( 'Facebook Pixel ID', 'wp-link-bio' ),
            'wplb_fb_pixel_id_cb',
            'wp-link-bio',
            'wplb_section_integration_settings',
            [
            'label_for'   => 'wplb_fb_pixel_id',
            'class'       => 'wplb-row',
            'placeholder' => 'XXXXXXXXXXXXXXX',
        ]
        );
        add_settings_field(
            'wplb_ga_tracking_code',
            __( 'Google Analytics Tracking ID', 'wp-link-bio' ),
            'wplb_ga_tracking_code_cb',
            'wp-link-bio',
            'wplb_section_integration_settings',
            [
            'label_for'   => 'wplb_ga_tracking_code',
            'class'       => 'wplb-row',
            'placeholder' => 'UA-XXXXXXXXX-X',
        ]
        );
        add_settings_field(
            'wplb_gtm_code',
            __( 'Google Tag Manager Code', 'wp-link-bio' ),
            'wplb_gtm_code_cb',
            'wp-link-bio',
            'wplb_section_integration_settings',
            [
            'label_for'   => 'wplb_gtm_code',
            'class'       => 'wplb-row',
            'placeholder' => 'GTM-XXXXXXX',
        ]
        );
    }
    
    add_action( 'admin_init', 'wplb_settings' );
    function wplb_section_general_settings_cb( $args )
    {
        ?>
        <p id="<?php 
        echo  esc_attr( $args['id'] ) ;
        ?>"><?php 
        esc_html_e( 'Utilize os campos abaixo para configurar o plugin.', 'wp-link-bio' );
        ?></p>
        <?php 
    }
    
    function wplb_link_bio_cb( $args )
    {
        $endpoint = get_option( 'wplb_endpoint' );
        
        if ( $endpoint ) {
            ?>
        <input type="text" name="wplb_link" class="wplb-link" value="<?php 
            echo  esc_attr( site_url( $endpoint ) ) ;
            ?>" size="50" readonly />
        <a href="#" class="wplb-copy-link button"><?php 
            _e( 'Copy Link', 'wp-link-bio' );
            ?></a>
        <p class="description" id="tagline-description"><?php 
            _e( 'This is the link to add to your profile bio.', 'wp-link-bio' );
            ?></p>
        <?php 
        }
    
    }
    
    function wplb_endpoint_cb( $args )
    {
        $endpoint = get_option( 'wplb_endpoint', 'ig' );
        $pages = get_pages();
        ?>
        <select name="wplb_endpoint" id="<?php 
        echo  esc_attr( $args['label_for'] ) ;
        ?>">
            <?php 
        foreach ( $pages as $page ) {
            ?>
            <option value="<?php 
            echo  $page->post_name ;
            ?>" <?php 
            selected( $endpoint, $page->post_name );
            ?>><?php 
            echo  $page->post_title ;
            ?></option>
            <?php 
        }
        ?>
        </select>
        <?php 
    }
    
    function wplb_template_cb( $args )
    {
        ?>
            <input type="hidden" name="wplb_template" value="link" />
            <?php 
    }
    
    function wplb_num_posts_cb( $args )
    {
        $links = get_option( 'wplb_num_posts', '10' );
        ?>
        <input type="number"  
            name="wplb_num_posts" 
            id="<?php 
        echo  esc_attr( $args['label_for'] ) ;
        ?>"
            value="<?php 
        echo  esc_attr( $links ) ;
        ?>" 
            min="-1"
            />
        <?php 
    }
    
    function wplb_logo_url_cb( $args )
    {
        $logo_url = get_option( 'wplb_logo_url' );
        $default_image = plugins_url( 'images/placeholder.png', __FILE__ );
        if ( empty($logo_url) ) {
            $logo_url = $default_image;
        }
        ?>
        <div class="upload">
            <img class="wplb-image" data-src="<?php 
        echo  $default_image ;
        ?>" src="<?php 
        echo  $logo_url ;
        ?>" height="100" style="border: 1px solid #ccc; margin-bottom: 20px;" />
            <div>
                <input type="hidden" name="wplb_logo_url" id="<?php 
        echo  esc_attr( $args['label_for'] ) ;
        ?>" value="<?php 
        echo  esc_attr( $logo_url ) ;
        ?>" />
                <button type="submit" class="wplb-upload-image button"><?php 
        _e( 'Upload', 'wp-link-bio' );
        ?></button>
                <button type="submit" class="wplb-remove-image button">&times;</button>
            </div>
        </div>
        
        <?php 
    }
    
    function wplb_body_bg_color_cb( $args )
    {
        $body_bg_color = get_option( 'wplb_body_bg_color' );
        ?>
        <input type="text"  
            name="wplb_body_bg_color"
            class="wplb-color-picker" 
            id="<?php 
        echo  esc_attr( $args['label_for'] ) ;
        ?>"
            value="<?php 
        echo  esc_attr( $body_bg_color ) ;
        ?>"
            minlength="4"
            maxlength="7"/>
        <?php 
    }
    
    function wplb_body_link_color_cb( $args )
    {
        $body_link_color = get_option( 'wplb_body_link_color' );
        ?>
        <input type="text"  
            name="wplb_body_link_color" 
            class="wplb-color-picker" 
            id="<?php 
        echo  esc_attr( $args['label_for'] ) ;
        ?>"
            value="<?php 
        echo  esc_attr( $body_link_color ) ;
        ?>"
            minlength="4"
            maxlength="7"/>
        <?php 
    }
    
    function wplb_fb_pixel_id_cb( $args )
    {
        // UA-134626752-1
        $fb_pixel_id = get_option( 'wplb_fb_pixel_id' );
        ?>
        <input type="text"  
            name="wplb_fb_pixel_id" 
            id="<?php 
        echo  esc_attr( $args['label_for'] ) ;
        ?>"
            placeholder="<?php 
        echo  esc_attr( $args['placeholder'] ) ;
        ?>"
            value="<?php 
        echo  esc_attr( $fb_pixel_id ) ;
        ?>" />
        <?php 
    }
    
    function wplb_ga_tracking_code_cb( $args )
    {
        // UA-134626752-1
        $ga_tracking_code = get_option( 'wplb_ga_tracking_code' );
        ?>
        <input type="text"  
            name="wplb_ga_tracking_code" 
            id="<?php 
        echo  esc_attr( $args['label_for'] ) ;
        ?>"
            placeholder="<?php 
        echo  esc_attr( $args['placeholder'] ) ;
        ?>"
            value="<?php 
        echo  esc_attr( $ga_tracking_code ) ;
        ?>" />
        <?php 
    }
    
    function wplb_gtm_code_cb( $args )
    {
        // GTM-N9VP4CK
        $gtm_code = get_option( 'wplb_gtm_code' );
        ?>
        <input type="text"  
            name="wplb_gtm_code" 
            id="<?php 
        echo  esc_attr( $args['label_for'] ) ;
        ?>"
            placeholder="<?php 
        echo  esc_attr( $args['placeholder'] ) ;
        ?>"
            value="<?php 
        echo  esc_attr( $gtm_code ) ;
        ?>" />
        <?php 
    }
    
    function wplb_options_page_html()
    {
        if ( !current_user_can( 'manage_options' ) ) {
            return;
        }
        /* if ( isset( $_GET['settings-updated'] ) ) {
               add_settings_error( 'wplb_messages', 'wplb_message', __( 'Configurações Salvas', 'wp-link-bio' ), 'updated' );
           } */
        settings_errors( 'wplb_messages' );
        ?>
        <div class="wrap">
            <h1><?php 
        esc_html_e( get_admin_page_title() );
        ?></h1>
            <form action="options.php" method="post">
            <?php 
        settings_fields( 'wp-link-bio' );
        do_settings_sections( 'wp-link-bio' );
        do_settings_sections( 'wp-link-bio-page-settings' );
        submit_button( __( 'Update Settings', 'wp-link-bio' ) );
        ?>
            </form>
        </div>
        <?php 
    }
    
    function wplb_get_link_url( $value )
    {
        global  $post ;
        $link_url = get_post_meta( $post->ID, $value, true );
        if ( !empty($link_url) ) {
            return ( is_array( $link_url ) ? stripslashes_deep( $link_url ) : stripslashes( wp_kses_decode_entities( $link_url ) ) );
        }
        return false;
    }
    
    function wplb_register_link_url_metabox()
    {
        add_meta_box(
            'wplb-meta-box-for-links',
            __( 'Link Attributes', 'wp-link-bio' ),
            'wplb_meta_box_output_for_link_url',
            'wp-link-bio',
            'normal'
        );
        //show in custom post
    }
    
    add_action( 'add_meta_boxes', 'wplb_register_link_url_metabox' );
    // Metabox Output
    function wplb_meta_box_output_for_link_url( $post )
    {
        // create a wp nonce field
        wp_nonce_field( 'wplb_nonce_links', 'my_nonce_links' );
        ?>
        
        <p>
            <label for="wplb-link-url"><?php 
        _e( 'Link URL', 'wp-link-bio' );
        ?>:</label>
            <input type="url" name="wplb_link_url" id="wplb-link-url" value="<?php 
        echo  wplb_get_link_url( 'wplb_link_url' ) ;
        ?>" size="100" />
        </p>
        
        <?php 
    }
    
    // Save the Metabox values with Post ID
    function wplb_save_metabox_link_url( $post_id )
    {
        // Stop the script when doing autosave
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
            return;
        }
        // Verify the nonce. If is not there, stop the script
        if ( !isset( $_POST['my_nonce_links'] ) || !wp_verify_nonce( $_POST['my_nonce_links'], 'wplb_nonce_links' ) ) {
            return;
        }
        // Stop the script if the user does not have edit permissions
        if ( !current_user_can( 'edit_post' ) ) {
            return;
        }
        // Save the Link URL field
        if ( isset( $_POST['wplb_link_url'] ) ) {
            update_post_meta( $post_id, 'wplb_link_url', esc_attr( $_POST['wplb_link_url'] ) );
        }
    }
    
    add_action( 'save_post', 'wplb_save_metabox_link_url' );
    function wplb_template_include( $template )
    {
        global  $wp_query ;
        $wplb_endpoint = get_option( 'wplb_endpoint' );
        if ( $wplb_endpoint !== $wp_query->query_vars['name'] ) {
            return $template;
        }
        $wplb_template = get_option( 'wplb_template', 'link' );
        if ( $wplb_template === 'link' ) {
            $template = plugin_dir_path( __FILE__ ) . 'templates/template-links.php';
        }
        return $template;
    }
    
    add_filter( 'template_include', 'wplb_template_include' );
}
